/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest;

import org.skife.jdbi.v2.DBI;
import org.skife.jdbi.v2.IDBI;

import com.akiban.rest.dbo.SqlGroupHelper;
import com.akiban.rest.dbo.SqlPrimaryKeyHelper;
import com.akiban.rest.util.ConnectionCloseFilter;
import com.akiban.rest.util.Props;
import com.google.inject.name.Names;
import com.google.inject.servlet.ServletModule;
import com.jolbox.bonecp.BoneCPDataSource;
import com.sun.jersey.guice.spi.container.servlet.GuiceContainer;

/**
 * Guice Module which registers essential classes - this is the collection of
 * bindings for both stand-alone and plugin use.
 */
public class RestServiceModule extends ServletModule {
	@Override
	protected void configureServlets() {
		bind(String.class).annotatedWith(
				Names.named("com.akiban.rest.config.prefix")).toInstance(
				"plugins.rest.");
		bind(Props.class).asEagerSingleton();

		BoneCPDataSource dataSource = new BoneCPDataSource();
		bind(BoneCPDataSource.class).toInstance(dataSource);
		bind(IDBI.class).toInstance(new DBI(dataSource));
		bind(FaviconResource.class).asEagerSingleton();
		bind(DataAccessOperationsResource.class).asEagerSingleton();
		bind(SqlGroupsResource.class).asEagerSingleton();
		bind(SqlQueryResource.class).asEagerSingleton();
		bind(SqlSchemataResource.class).asEagerSingleton();
		bind(SqlTablesResource.class).asEagerSingleton();
		bind(SqlExecutionResource.class).asEagerSingleton();
		bind(VersionResource.class).asEagerSingleton();
		bind(ConnectionCloseFilter.class).asEagerSingleton();
		bind(SqlPrimaryKeyHelper.class).asEagerSingleton();
		bind(SqlGroupHelper.class).asEagerSingleton();

		serve("*").with(GuiceContainer.class);
		filter("*").through(ConnectionCloseFilter.class);
	}
}