/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest;

import java.util.Arrays;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import com.akiban.rest.dbo.JdbcDataSource;
import com.google.inject.Inject;

/**
 * Easy access to table groups
 */
@Path("/groups")
public class SqlGroupsResource {
	private static final String GROUPS_QUERY = "select * from information_schema.grouping_constraints where root_schema_name = ?";

	@Inject
	private JdbcDataSource store;

	@GET
	@Path("/{schema}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response getGroups(@PathParam("schema") String schema,
			@QueryParam("format") String format,
			@QueryParam("jsoncallback") String jsonp) throws Exception {
		//
		// FIXME: bulletproof the query verification
		//
		return store.query(format, jsonp, GROUPS_QUERY, Arrays.asList(schema));
	}
}
