/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest;

import java.util.Arrays;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import com.akiban.rest.dbo.JdbcDataSource;
import com.google.inject.Inject;

/**
 * Easy access to all tables within a schema, or a specific table
 */
@Path("/tables")
public class SqlTablesResource {
	private static final String SCHEMA_TABLES_QUERY = "select * from information_schema.tables where table_schema = ?";
	private static final String SINGLE_TABLE_QUERY = "select *, "
			+ " (select * from information_schema.columns where schema_name = t.table_schema and table_name = t.table_name) as columns, "
			+ " (select *, "
			+ "   (select * from information_schema.index_columns where schema_name = i.schema_name and index_table_name = i.table_name and index_name = i.index_name) as index_columns "
			+ "   from information_schema.indexes i where schema_name = t.table_schema and table_name = t.table_name) as indexes, "
			+ " (select * from information_schema.table_constraints where schema_name = t.table_schema and table_name = t.table_name) as table_constraints "
			+ " from information_schema.tables t where table_schema = ? and table_name = ?";

	@Inject
	private JdbcDataSource store;

	@GET
	@Path("/{schemaObject}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response getTableDetails(
			@PathParam("schemaObject") String schemaObject,
			@QueryParam("format") String format,
			@QueryParam("jsoncallback") String jsonp) throws Exception {
		//
		// FIXME: bulletproof the query verification
		//
		int pos = schemaObject != null ? schemaObject.indexOf(".") : -1;

		if (pos != -1) {
			String schema = schemaObject.substring(0, pos);
			String table = schemaObject.substring(pos + 1);

			return store.query(format, jsonp, SINGLE_TABLE_QUERY,
					Arrays.asList(schema, table));
		}

		return store.query(format, jsonp, SCHEMA_TABLES_QUERY,
				Arrays.asList(schemaObject));
	}
}
