/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest.dbo;

import java.util.Iterator;
import java.util.Map;

import org.skife.jdbi.v2.Handle;
import org.skife.jdbi.v2.Query;
import org.skife.jdbi.v2.Update;

import com.akiban.rest.util.StreamingJsonResult;

/**
 * Helper functions for working with SQL.
 */
public class SqlHelper {
	public static Query<Map<String, Object>> getEntityQuery(
			final SqlGroupHelper groupHelper, final Handle handle,
			final String schema, final String table, Map<String, ?> key,
			final Integer depth) throws Exception {
		//
		// FIXME: do proper quoting
		//
		StringBuilder baseQuery = new StringBuilder();

		baseQuery.append(groupHelper.getRecursiveGroupSelect(handle, schema,
				table, depth, null, null));

		baseQuery.append(" where ");

		Iterator iter = key.entrySet().iterator();

		while (iter.hasNext()) {
			Map.Entry<String, ?> entry = (Map.Entry<String, ?>) iter.next();
			baseQuery.append(entry.getKey());
			baseQuery.append(" = ? ");
			if (iter.hasNext()) {
				baseQuery.append(" AND ");
			}
		}

		Query<Map<String, Object>> query = handle.createQuery(baseQuery
				.toString());

		int i = 0;
		for (Map.Entry<String, ?> entry : key.entrySet()) {
			query.bind(i, entry.getValue());
			i += 1;
		}

		return query;
	}

	public static Update getEntityDeleteQuery(final SqlGroupHelper groupHelper,
			final Handle handle, final String schema, final String table,
			Map<String, ?> key) throws Exception {
		//
		// FIXME: do proper quoting
		//
		StringBuilder baseQuery = new StringBuilder();

		baseQuery.append("delete from ");
		baseQuery.append(getTableName(schema, table));
		baseQuery.append(" where ");

		Iterator iter = key.entrySet().iterator();

		while (iter.hasNext()) {
			Map.Entry<String, ?> entry = (Map.Entry<String, ?>) iter.next();
			baseQuery.append(entry.getKey());
			baseQuery.append(" = ? ");
			if (iter.hasNext()) {
				baseQuery.append(" AND ");
			}
		}

		Update update = handle.createStatement(baseQuery.toString());

		int i = 0;
		for (Map.Entry<String, ?> entry : key.entrySet()) {
			update.bind(i, entry.getValue());
			i += 1;
		}

		return update;
	}

	public static void printResultSet(StreamingJsonResult output,
			Iterator<Map<String, Object>> iterator, boolean expectResult) {
		if (iterator.hasNext()) {
			while (iterator.hasNext()) {
				if (iterator.hasNext()) {
					output.writeJsonString((String) iterator.next().get("JSON"));
				} else {
					output.writeJsonString("null");
				}
			}
		} else {
			if (expectResult) {
				output.writeJsonString("null");
			}
		}
	}

	public static String getTableName(String schema, String table) {
		//
		// FIXME: do proper quoting/escaping
		//
		return (schema != null && schema.length() > 0) ? quote(schema) + "."
				+ quote(table) : quote(table);
	}

	public static String getColumnName(String schema, String table,
			String column) {
		//
		// FIXME: do proper quoting/escaping
		//
		return getTableName(schema, table) + "." + quote(column);
	}

	public static String quote(String value) {
		//
		// FIXME: do proper quoting/escaping
		//
		return "`" + value + "`";
	}
}
