/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest.model;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;

import com.akiban.rest.util.EncodingUtil;

/**
 * Encapsulates JSON objects destined for database entry and modification.
 */
public class Entity {
	private final String schema;
	private final String table;
	private final PrimaryKeyInfo primaryKeyInfo;
	private final Map<String, Object> attributes;
	private final Map<String, Entity> enclosingEntities;

	public Entity(String schema, String table, PrimaryKeyInfo pkInfo,
			Map<String, Object> attributes,
			Map<String, Entity> enclosingEntities) {
		this.schema = schema;
		this.table = table;
		this.primaryKeyInfo = pkInfo;

		Map<String, Object> newAttr = new LinkedHashMap<String, Object>();
		newAttr.putAll(attributes);
		this.attributes = Collections.unmodifiableMap(newAttr);

		Map<String, Entity> newEnclose = new LinkedHashMap<String, Entity>();
		newAttr.putAll(enclosingEntities);
		this.enclosingEntities = Collections.unmodifiableMap(newEnclose);
	}

	public String getSchema() {
		return schema;
	}

	public String getTable() {
		return table;
	}

	public Map<String, Object> getAttributes() {
		return attributes;
	}

	public PrimaryKeyInfo getPrimaryKeyInfo() {
		return primaryKeyInfo;
	}

	public Map<String, Object> getPrimaryKey() {
		return primaryKeyInfo.getPrimaryKey(attributes);
	}

	public Map<String, Entity> getEnclosingEntities() {
		return enclosingEntities;
	}

	@Override
	public String toString() {
		return "Entity:" + EncodingUtil.toJson(this);
	}
}