/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest.model;

import com.akiban.rest.util.EncodingUtil;

/**
 * Encapsulates relevant information about table groups.
 */
public class GroupInfo {
	private final String parentSchema;
	private final String parentTable;
	private final String childSchema;
	private final String childTable;
	private final int leftPos;
	private final String leftKey;
	private final int rightPos;
	private final String rightKey;

	public GroupInfo(String parentSchema, String parentTable,
			String childSchema, String childTable, int leftPos, String leftKey,
			int rightPos, String rightKey) {
		this.parentSchema = parentSchema;
		this.parentTable = parentTable;
		this.childSchema = childSchema;
		this.childTable = childTable;
		this.leftPos = leftPos;
		this.leftKey = leftKey;
		this.rightPos = rightPos;
		this.rightKey = rightKey;
	}

	public String getParentSchema() {
		return parentSchema;
	}

	public String getParentTable() {
		return parentTable;
	}

	public String getChildSchema() {
		return childSchema;
	}

	public String getChildTable() {
		return childTable;
	}

	public int getLeftPos() {
		return leftPos;
	}

	public String getLeftKey() {
		return leftKey;
	}

	public int getRightPos() {
		return rightPos;
	}

	public String getRightKey() {
		return rightKey;
	}

	@Override
	public String toString() {
		return "GroupInfo:" + EncodingUtil.toJson(this);
	}
}