/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.Map;
import java.util.Properties;

import com.akiban.server.service.config.ConfigurationService;
import com.akiban.server.service.config.PropertyNotDefinedException;
import com.google.inject.Inject;
import com.google.inject.name.Named;

/**
 * Trivial implementation of a ConfigurationService suitable for stand-alone
 * RestService use.
 */
public class BasicConfigurationService implements ConfigurationService {
	private final String prefix;
	private final Properties properties;

	@Inject
	public BasicConfigurationService(
			@Named("com.akiban.rest.config.prefix") String prefix,
			@Named("com.akiban.rest.config.resource") String resource) {
		this.prefix = prefix;
		this.properties = new Properties();

		InputStream input = null;
		try {
			input = getClass().getClassLoader().getResourceAsStream(resource);
			properties.load(input);
		} catch (IOException e) {
			throw new RuntimeException("Error while loading properties!", e);
		} finally {
			if (input != null) {
				try {
					input.close();
				} catch (IOException ignored) {
				}
			}
		}
	}

	@Override
	public Properties deriveProperties(String withPrefix) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Map<String, String> getProperties() {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getProperty(String globalProperty)
			throws PropertyNotDefinedException {
		if (!globalProperty.startsWith(prefix)) {
			throw new IllegalArgumentException(
					"Illegal property name, must start with '" + prefix + "': "
							+ globalProperty);
		}

		String localProperty = globalProperty.substring(prefix.length());

		if (System.getProperty(globalProperty) != null) {
			return System.getProperty(globalProperty);
		}

		if (properties.containsKey(localProperty)) {
			return properties.getProperty(localProperty);
		}

		throw new RuntimeException("Property not found! " + globalProperty);
	}

	@Override
	public long queryTimeoutSec() {
		throw new UnsupportedOperationException();
	}

	@Override
	public void queryTimeoutSec(long queryTimeoutSec) {
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean testing() {
		throw new UnsupportedOperationException();
	}
}
