/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest;

import java.util.List;
import java.util.Map;

import javax.ws.rs.core.Response;

import org.testng.Assert;
import org.testng.annotations.Test;

import com.google.common.collect.ImmutableMap;

/**
 * Test cases for the SqlExecutionResource - essentially making sure that the
 * POST lines of SQL DDL works.
 */
@Test
public class SqlExecutionResourceTest {
	private SqlExecutionResource exec = TestHelper
			.get(SqlExecutionResource.class);

	public void testExecuteDdlCreate() throws Exception {
		Response response = exec.execute(null, null,
				TestHelper.getResource("com/akiban/rest/exec_01_create.sql"));

		List<Map<String, Object>> result = TestHelper.getObject(List.class,
				response);

		Assert.assertEquals(result.size(), 2);
		TestHelper.assertMatch(result.get(0), ImmutableMap.<String, Object> of(
				"line", 1, "status", "OK", "sql",
				"drop table if exists t20121113.table_01;"));
		TestHelper
				.assertMatch(
						result.get(1),
						ImmutableMap
								.<String, Object> of(
										"line",
										2,
										"status",
										"OK",
										"sql",
										"create table t20121113.table_01(a int primary key not null generated by default as identity);"));
	}

	public void testExecuteDdlDrop() throws Exception {
		Response response = exec.execute(null, null,
				TestHelper.getResource("com/akiban/rest/exec_01_drop.sql"));

		List<Map<String, Object>> result = TestHelper.getObject(List.class,
				response);

		Assert.assertEquals(result.size(), 1);
		TestHelper.assertMatch(result.get(0), ImmutableMap.<String, Object> of(
				"line", 1, "status", "OK", "sql",
				"drop table if exists t20121113.table_01;"));
	}
}
