/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest;

import java.util.List;
import java.util.Map;

import javax.ws.rs.core.Response;

import org.testng.Assert;
import org.testng.annotations.Test;

import com.google.common.collect.ImmutableMap;

/**
 * Test cases for the SqlQueryResource - making sure that the ability to do
 * free-form SELECT queries works.
 */
@Test
public class SqlQueryResourceTest {
	private SqlQueryResource query = TestHelper.get(SqlQueryResource.class);

	public void testSelectFromTable() throws Exception {
		Response response = query
				.getQueryResults(
						null,
						null,
						"select * from information_schema.tables where table_schema = 'information_schema' and table_name = 'columns'");

		Map<String, Object> result = (Map<String, Object>) TestHelper
				.getObject(List.class, response).get(0);

		TestHelper.assertMatch(result, ImmutableMap.<String, Object> of(
				"table_schema", (Object) "information_schema", "table_name",
				"columns", "table_type", "DICTIONARY VIEW", "table_id",
				1000000010));
	}

	public void testSelectCount() throws Exception {
		Response response = query
				.getQueryResults(
						null,
						null,
						"select count(*) as count from information_schema.tables where table_schema = 'information_schema' and table_name like 'storage_%'");

		List<Map<String, Object>> result = TestHelper.getObject(List.class,
				response);

		Assert.assertEquals(result.size(), 1);
		TestHelper.assertMatch(result.get(0),
				ImmutableMap.<String, Integer> of("count", 11));
	}

	public void testSelectMultipleRows() throws Exception {
		Response response = query
				.getQueryResults(
						null,
						null,
						"select * from information_schema.tables where table_schema = 'information_schema' and table_name like 'storage_%'");

		List<Map<String, Object>> result = TestHelper.getObject(List.class,
				response);

		Assert.assertEquals(result.size(), 11);
		TestHelper.assertMatch(result.get(0), ImmutableMap.<String, String> of(
				"table_name", "storage_alert_summary"));
		TestHelper.assertMatch(result.get(10), ImmutableMap
				.<String, String> of("table_name", "storage_volumes"));
	}
}
