/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest;

import java.util.List;

import javax.ws.rs.core.Response;

import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * Test cases for the SqlSchemataResource - making sure schema information
 * retrieval works properly.
 */
@Test
public class SqlSchemataResourceTest {
	private SqlExecutionResource exec = TestHelper
			.get(SqlExecutionResource.class);
	private SqlSchemataResource schema = TestHelper
			.get(SqlSchemataResource.class);

	public void testSchemata() throws Exception {
		TestHelper.executeSql(exec, "com/akiban/rest/exec_01_drop.sql");
		List<?> listBefore = getSchemata();

		Assert.assertTrue(listBefore.contains("information_schema"));
		Assert.assertFalse(listBefore.contains("t20121113"));

		TestHelper.executeSql(exec, "com/akiban/rest/exec_01_create.sql");
		List<?> listAfter = getSchemata();

		Assert.assertTrue(listAfter.contains("information_schema"));
		Assert.assertTrue(listAfter.contains("t20121113"));

		TestHelper.executeSql(exec, "com/akiban/rest/exec_01_drop.sql");
	}

	private List<?> getSchemata() throws Exception {
		Response response = schema.getSchemata(null, null);
		List<?> list = TestHelper.collectList(
				TestHelper.getObject(List.class, response), "schema_name");

		return list;
	}
}
