/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest.util;

import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * Exercise the corners of the configuration service.
 */
@Test
public class BasicConfigurationServiceTest {
	public void testMissingConfiguration() {
		try {
			new BasicConfigurationService("prefix.",
					"path/to/nonexistent.properties");
			Assert.fail("expected exception");
		} catch (RuntimeException expected) {
			Assert.assertTrue(expected instanceof NullPointerException);
		}
	}

	public void testValidConfiguration() {
		BasicConfigurationService config = new BasicConfigurationService(
				"plugins.rest.",
				"com/akiban/server/plugin-configuration.properties");

		Assert.assertNotNull(config.getProperty("plugins.rest.http.port"));

		try {
			config.getProperty("plugins.rest.nonexistent");
			Assert.fail("expected exception");
		} catch (RuntimeException expected) {
			Assert.assertEquals(expected.getMessage(),
					"Property not found! plugins.rest.nonexistent");
		}

		try {
			config.getProperty("nonexistent");
			Assert.fail("expected exception");
		} catch (IllegalArgumentException expected) {
			Assert.assertEquals(expected.getMessage(),
					"Illegal property name, must start with 'plugins.rest.': nonexistent");
		}
	}
}
