/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.akiban.rest.util;

import java.util.Collections;
import java.util.LinkedHashMap;

import org.codehaus.jackson.JsonParseException;
import org.codehaus.jackson.map.JsonMappingException;
import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * Exercise the corners of JSON encoding and decoding.
 */
@Test
public class EncodingUtilTest {
	public void testToJson() {
		Assert.assertEquals(EncodingUtil.toJson(null), "null");
		try {
			Assert.assertEquals(EncodingUtil.toJson(this), "ignoreme");
			Assert.fail("expected exception");
		} catch (RuntimeException expected) {
			Assert.assertTrue(expected.getCause() instanceof JsonMappingException);
		}
	}

	public void testFromJsonString() {
		Assert.assertEquals(EncodingUtil.fromJson(LinkedHashMap.class, "{}"),
				Collections.emptyMap());
		try {
			Assert.assertEquals(
					EncodingUtil.fromJson(LinkedHashMap.class, "{".getBytes()),
					"ignoreme");
			Assert.fail("expected exception");
		} catch (RuntimeException expected) {
			Assert.assertTrue(expected.getCause() instanceof JsonParseException);
		}
	}

	public void testFromJsonBytes() {
		Assert.assertEquals(
				EncodingUtil.fromJson(LinkedHashMap.class, "{}".getBytes()),
				Collections.emptyMap());
		try {
			Assert.assertEquals(
					EncodingUtil.fromJson(LinkedHashMap.class, "{"), "ignoreme");
			Assert.fail("expected exception");
		} catch (RuntimeException expected) {
			Assert.assertTrue(expected.getCause() instanceof JsonParseException);
		}
	}
}
